@@ -41,7 +41,7 @@ from .runners import (
 from distutils.sysconfig import get_config_var
 
 # if sys.version_info[0] == 2:  # python 2
-sharedext = get_config_var('SO')
+sharedext = get_config_var('EXT_SUFFIX')
 # else:
 #    sharedext = get_config_var('EXT_SUFFIX')
 
@@ -535,7 +535,7 @@ def pyx2obj(pyxpath, objpath=None, interm_c_dir=None, cwd=None,
     cy_kwargs = cy_kwargs or {}
     cy_kwargs['output_dir'] = cwd
     if cplus is None:
-        cplus = pyx_is_cplus(pyxpath)
+        cplus = pyx_is_cplus(pyxpath if pyxpath.startswith('/') else os.path.join(cwd, pyxpath))
     cy_kwargs['cplus'] = cplus
     if gdb:
         cy_kwargs['gdb_debug'] = True
@@ -702,14 +702,16 @@ def compile_link_import_strings(codes, build_dir=None, **kwargs):
         md5_in_mem = md5_of_string(code_.encode('utf-8')).hexdigest()
         if only_update and os.path.exists(dest):
             if os.path.exists(dest+'.md5'):
-                md5_on_disk = open(dest+'.md5', 'rt').read()
+                with open(dest+'.md5', 'rt') as ifh:
+                    md5_on_disk = ifh.read()
             else:
                 md5_on_disk = md5_of_file(dest).hexdigest()
             differs = md5_on_disk != md5_in_mem
         if not only_update or differs:
-            with open(dest, 'wt') as fh:
-                fh.write(code_)
-                open(dest+'.md5', 'wt').write(md5_in_mem)
+            with open(dest, 'wt') as ofh:
+                ofh.write(code_)
+                with open(dest+'.md5', 'wt') as ofh_md5:
+                    ofh_md5.write(md5_in_mem)
         source_files.append(dest)
 
     return compile_link_import_py_ext(
